@@ -7,13 +7,11 @@ import shutil
 class TestModel(unittest.TestCase):
 
     def setUp(self):
-        self.data = tsag.preprocessing.PreprocessDatasets('tourism', test_size=228*30).apply_preprocess()
+        self.data = tsag.preprocessing.PreprocessDatasets('tourism', test_size=228*10).apply_preprocess()
         self.n = self.data['predict']['n']
         self.s = self.data['train']['s']
         shutil.rmtree("./data/original_datasets")
-        self.mint = MinT(dataset='tourism', groups=self.data,
-                         store_prediction_samples=True,
-                         store_prediction_points=True)
+        self.mint = MinT(dataset='tourism', groups=self.data)
 
     @classmethod
     def tearDownClass(cls):
@@ -34,4 +32,4 @@ class TestModel(unittest.TestCase):
     def test_predict_shape(self):
         forecasts = self.mint.train()
         df_results = self.mint.results(forecasts)
-        self.assertTrue(df_results.shape == (576, 11))
+        self.assertTrue(df_results.shape == (1872, 11))
