@@ -36,7 +36,6 @@ class DeepAR:
         self.wall_time_predict = None
         self.wall_time_total = None
         self.input_dir = input_dir
-        self._create_directories()
         self.stat_cat_cardinalities = [
             v for k, v in self.groups["train"]["groups_n"].items()
         ]
@@ -84,10 +83,6 @@ class DeepAR:
             log_dir=log_dir,
         )
 
-    def _create_directories(self):
-        # Create directory to store results if does not exist
-        Path(f"{self.input_dir}results").mkdir(parents=True, exist_ok=True)
-
     def _build_train_ds(self):
         train_target_values = self.groups["train"]["data"].T
 
@@ -187,7 +182,7 @@ class DeepAR:
 
     def store_metrics(self, res, track_mem=True):
         with open(
-            f"{self.input_dir}results/results_gp_cov_{self.dataset}.pickle", "wb"
+            f"{self.input_dir}results_gp_cov_{self.dataset}.pickle", "wb"
         ) as handle:
             if track_mem:
                 process = psutil.Process(os.getpid())
