@@ -31,7 +31,6 @@ class MinT:
         self.groups['train']['groups_idx'] = self._get_capitalized_keys(self.groups['train']['groups_idx'])
         self.groups['train']['groups_n'] = self._get_capitalized_keys(self.groups['train']['groups_n'])
         self.input_dir = input_dir
-        self._create_directories()
         dict_groups = {k.capitalize(): np.tile(groups['train']['groups_names'][k][groups['train']['groups_idx'][k]],
                                                (groups['predict']['n'], 1)).T.reshape(-1, ) for k in
                        [k for k, v in groups['train']['groups_n'].items()]}
@@ -71,10 +70,6 @@ class MinT:
             "metrics", algorithm='mint', dataset=self.dataset, to_file=True, log_dir=log_dir
         )
 
-    def _create_directories(self):
-        # Create directory to store results if does not exist
-        Path(f'{self.input_dir}results').mkdir(parents=True, exist_ok=True)
-
     def train(self, algorithm='ets', rec_method='mint', track_mem=True):
         """Train ETS or ARIMA with conventional bottom-up or MinT reconciliation strategies
 
@@ -228,7 +223,7 @@ class MinT:
         return pred_mint
 
     def store_metrics(self, res, track_mem=True):
-        with open(f'{self.input_dir}results/results_gp_cov_{self.dataset}.pickle', 'wb') as handle:
+        with open(f"{self.input_dir}results_gp_cov_{self.dataset}.pickle", 'wb') as handle:
             if track_mem:
                 process = psutil.Process(os.getpid())
                 mem = process.memory_info().rss / (1024**3)
